import { promises as fs, existsSync } from "fs"
import { webcrypto } from "crypto"
import { join } from "path"
import type { Adapter } from "./index"

/**
 * Default Node.js adapter. This can be used while using `opvault.js`
 * in a Node.js environment.
 */
export const adapter: Adapter = {
  fs: {
    readTextFile: path => fs.readFile(path, "utf-8"),
    readFile: path => fs.readFile(path),
    writeTextFile: fs.writeFile,
    async *readDir(path) {
      const names = await fs.readdir(path)
      for (const name of names) {
        const fullPath = join(path, name)
        const stat = await fs.stat(fullPath)
        yield {
          name,
          isFile: stat.isFile(),
          isDirectory: stat.isDirectory(),
        }
      }
    },

    exists: async path => existsSync(path),
  },
  subtle: (webcrypto as any).subtle,
}
