import { useEffect, memo } from "react"
import { debounce } from "lodash-es"
import { useLocaleContext, useTranslate } from "./i18n"
import { Key, useStorage } from "./utils/localStorage"

const updateCSS = debounce((name: string, value: string) => {
  document.body.style.setProperty(name, value || null)
}, 500)

export const SideEffect = memo(() => {
  const { locale } = useLocaleContext()
  const t = useTranslate()

  useEffect(() => {
    document.documentElement.lang = locale
    document.title = t.label.app_name
  }, [locale])

  const [uiFont] = useStorage(Key.UI_FONT)
  const [monoFont] = useStorage(Key.MONOSPACE_FONT)

  useEffect(() => {
    updateCSS("--sans-serif", uiFont)
  }, [uiFont])

  useEffect(() => {
    updateCSS("--monospace", monoFont)
  }, [monoFont])

  return null
})
