import styled from "@emotion/styled"
import { memo, useEffect } from "react"

const Container = styled.div`
  background: rgba(255, 255, 255, 0.6);
  backdrop-filter: blur(4px);
  border-radius: 20px;
  font-family: var(--monospace);
  letter-spacing: 2px;
  position: fixed;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  font-size: 6em;
  text-align: center;
  padding: 20px 25px;
  word-break: break-word;
  min-width: 75vw;
  z-index: 2;
  @media (prefers-color-scheme: dark) {
    background: rgba(0, 0, 0, 0.6);
  }
`
const Letter = styled.span`
  &:nth-of-type(even) {
    opacity: 0.8;
  }
`

interface BigTextViewProps {
  onClose(): void
  children: string
}

export const BigTextView = memo<BigTextViewProps>(({ onClose, children }) => {
  useEffect(() => {
    const fn = (e: KeyboardEvent) => {
      if (e.code === "Escape") {
        onClose()
      }
    }
    document.addEventListener("keydown", fn)
    return () => document.removeEventListener("keydown", fn)
  }, [onClose])

  return (
    <Container>
      {children.split("").map((letter, i) => (
        <Letter key={i}>{letter}</Letter>
      ))}
    </Container>
  )
})
