import { memo, useMemo } from "react"
import styled from "@emotion/styled"
import type { ItemField, ItemSection } from "opvault.js"
import { ErrorBoundary } from "./ErrorBoundary"
import { ItemFieldValue, ItemDetailsFieldValue } from "./ItemFieldValue"

export { Container as FieldContainer }
const Container: React.FC = styled.div`
  padding: 5px 0;
  margin-bottom: 3px;
`
export const FieldTitle: React.FC = styled.div`
  font-size: 85%;
  margin-bottom: 3px;
  user-select: none;
`

export const ItemFieldView = memo<{
  field: ItemSection.Any
}>(({ field }) => {
  const title = useMemo(
    () => ((field as ItemSection.Concealed).n?.startsWith("TOTP_") ? "TOTP" : field.t),
    [field]
  )

  if (field.v == null) {
    return null
  }

  return (
    <ErrorBoundary>
      <Container>
        <FieldTitle>{title}</FieldTitle>
        <ItemFieldValue field={field} />
      </Container>
    </ErrorBoundary>
  )
})

const hideIds = new Set(["use_desktop", "use_mobile", "use_html"])
const hideNames = new Set(["remember"])

export const ItemDetailsFieldView = memo<{
  field: ItemField
}>(({ field }) => {
  if (field.value == null || hideIds.has(field.id!) || hideNames.has(field.name)) {
    return null
  }

  return (
    <ErrorBoundary>
      <Container>
        <FieldTitle>{field.name}</FieldTitle>
        <ItemDetailsFieldValue field={field} />
      </Container>
    </ErrorBoundary>
  )
})
