import type { ItemSection } from "opvault.js"
import { useCallback, useState } from "react"
import { useTranslate } from "../../i18n"
import { BigTextView } from "../BigTextView"
import { useItemFieldContextMenu } from "../ItemFieldContextMenu"
import { Container } from "./Container"
import { useCopy } from "./hooks"

export const Password: React.FC<{
  field: Pick<ItemSection.Concealed, "v">
}> = ({ field }) => {
  const t = useTranslate()
  const [show, setShow] = useState(false)
  const [bigText, showBigText] = useState(false)

  const { onRightClick, ContextMenuContainer, Item } = useItemFieldContextMenu()
  const onToggle = useCallback(() => setShow(x => !x), [])
  const onCopy = useCopy(field.v)
  const onOpenBigText = useCallback(() => {
    showBigText(true)
  }, [])
  const onCloseBigText = useCallback(() => {
    showBigText(false)
  }, [])

  return (
    <>
      <Container
        onContextMenu={onRightClick}
        onDoubleClick={() => setShow(x => !x)}
        onClick={onCopy}
        style={{
          fontFamily: "var(--monospace)",
          ...(!show && { userSelect: "none" }),
        }}
      >
        {show ? field.v : "·".repeat(10)}
      </Container>
      {bigText && <BigTextView onClose={onCloseBigText}>{field.v}</BigTextView>}
      <ContextMenuContainer>
        <Item onClick={onCopy}>{t.action.copy}</Item>
        <Item onClick={onToggle}>{show ? t.action.hide : t.action.show}</Item>
        {!bigText && (
          <Item onClick={onOpenBigText}>{t.action.show_in_big_characters}</Item>
        )}
      </ContextMenuContainer>
    </>
  )
}
