import type { ItemSection, ItemField } from "opvault.js"
import { FieldType } from "opvault.js"
import { ErrorBoundary } from "../ErrorBoundary"
import { Password } from "./Password"
import { OTP } from "./OTP"
import { MonthYear } from "./MonthYear"
import { DateView } from "./DateView"
import { TextView } from "./Text"
import { Address } from "./Address"

export const ItemFieldValue: React.FC<{
  field: ItemSection.Any
}> = ({ field }) => {
  if (field.v == null) {
    return null
  }

  switch (field.k) {
    case "concealed":
      return field.n.startsWith("TOTP_") ? (
        <OTP field={field} />
      ) : (
        <Password field={field} />
      )
    case "monthYear":
      return <MonthYear field={field} />
    case "date":
      return <DateView field={field} />
    case "address":
      return <Address field={field} />
  }

  return (
    <ErrorBoundary>
      <TextView value={field.v} />
    </ErrorBoundary>
  )
}

export const ItemDetailsFieldValue: React.FC<{
  field: ItemField
}> = ({ field }) => {
  if (field.type === FieldType.Password || field.designation === "password") {
    return <Password field={{ v: field.value } as any} />
  }

  return (
    <ErrorBoundary>
      <TextView value={field.value!} />
    </ErrorBoundary>
  )
}
