import { memo } from "react"
import styled from "@emotion/styled"
import { cx } from "@emotion/css"
import type { Item } from "opvault.js"
import { AiFillStar } from "react-icons/ai"
import { CategoryIcon } from "./CategoryIcon"
import { useTranslate } from "../i18n"
import { ItemNoTitle } from "../styles"

interface ListProps {
  items: Item[]
  selected?: Item
  onSelect(item: Item): void
}

const Container = styled.div``
const List = styled.ol`
  list-style: none;
  padding: 0;
`
const ItemView = styled.li`
  align-items: center;
  cursor: default;
  display: grid;
  grid-template-columns: 35px 1fr;
  padding: 5px 15px;
  position: relative;
  transition: background-color 0.1s;
  user-select: none;
  &:hover {
    background-color: var(--hover-background);
  }
  &.selected {
    background-color: var(--selected-background);
  }
  &.trashed {
    opacity: 0.6;
  }
`
const ItemTitle = styled.div`
  font-weight: 600;
  margin-bottom: 2px;
`

const ItemDescription = styled.div`
  font-size: 95%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 230px;
  &.empty {
    opacity: 0.4;
  }
`
const Icon = styled(CategoryIcon)`
  font-size: 1.5em;
`
const Favorite = styled(AiFillStar)`
  bottom: 10px;
  display: inline-block;
  fill: #fdcc0d;
  left: 10px;
  opacity: 0.9;
  position: absolute;
`

export const ItemList = memo<ListProps>(({ items, onSelect, selected }) => {
  const t = useTranslate()
  return (
    <Container>
      <List>
        {items.map(item => (
          <ItemView
            key={item.uuid}
            onClick={() => onSelect(item)}
            className={cx({
              selected: selected?.uuid === item.uuid,
              trashed: item.isDeleted,
            })}
          >
            <div>
              <Icon fill="#FFF" category={item.category} />
              {!!item.fave && <Favorite />}
            </div>
            <div>
              <ItemTitle>
                {item.overview.title || <ItemNoTitle>{t.label.no_title}</ItemNoTitle>}
              </ItemTitle>
              <ItemDescription className={cx(!item.overview.ainfo && "empty")}>
                {item.overview.ainfo || "-"}
              </ItemDescription>
            </div>
          </ItemView>
        ))}
      </List>
    </Container>
  )
})
