import fs, { promises } from "fs"
import { ipcMain, dialog } from "electron"
import { adapter } from "opvault.js/src/adapter/node"
import type { DirEntry } from "opvault.js/src/adapter"
import type { IPC } from "./ipc-types"

registerService({
  async showDirectoryPicker() {
    const result = await dialog.showOpenDialog({
      properties: ["openDirectory", "treatPackageAsDirectory"],
    })
    if (result.canceled || !result.filePaths.length) return
    return result.filePaths[0]
  },

  async pathExists(_, path) {
    return fs.existsSync(path)
  },

  async readFile(_, path) {
    return promises.readFile(path)
  },

  async readTextFile(_, path) {
    return promises.readFile(path, "utf-8")
  },

  async writeFile(_, path, content) {
    await promises.writeFile(path, content)
  },

  async readDir(_, path) {
    const entries: DirEntry[] = []
    for await (const dirent of adapter.fs.readDir(path)) {
      entries.push(dirent)
    }
    return entries
  },
})

/**
 * Listens to `channel`, when a new message arrives `listener` would be called
 * with `listener(event, ...args)`
 */
function registerService(listeners: {
  [K in keyof IPC]: (
    event: Electron.IpcMainEvent,
    ...args: Parameters<IPC[K]>
  ) => ReturnType<IPC[K]>
}) {
  for (const [key, value] of Object.entries(listeners)) {
    ipcMain.handle(`service-${key}`, value as any)
  }
}
