import type { Adapter } from "opvault.js/src/adapter"
import type { IPC } from "../electron/ipc-types"
import { memoize } from "./memoize"

declare const ipcRenderer: Electron.IpcRenderer

export async function openDirectory() {
  return ipc.showDirectoryPicker()
}

export const electronAdapter: Adapter = {
  fs: {
    exists: path => ipc.pathExists(path),
    readFile: path => ipc.readFile(path),
    readTextFile: path => ipc.readTextFile(path),
    async *readDir(path) {
      yield* await ipc.readDir(path)
    },
    writeTextFile: (path, data) => ipc.writeFile(path, data),
  },
  subtle: crypto.subtle,
}

const ipc = new Proxy<IPC>({} as any, {
  get: memoize(
    (_, channel: string) =>
      (...args: any[]) =>
        ipcRenderer.invoke(`service-${channel}`, ...args),
    (_, name) => name
  ),
})
