export function memoize<T extends (...args: any[]) => any, K>(
  fn: T,
  getKey: (...args: Parameters<T>) => K
): T {
  const map = new Map<K, ReturnType<T>>()
  function memoized(this: any, ...args: Parameters<T>): ReturnType<T> {
    const key = getKey(...args)
    if (map.has(key)) {
      return map.get(key)!
    } else {
      const value = fn.apply(this, args)
      map.set(key, value)
      return value
    }
  }
  Object.defineProperty(memoized, "name", { value: fn.name })
  return memoized as any
}
