import styled from "@emotion/styled"
import { keyframes } from "@emotion/css"
import React, { useCallback, useRef, useState } from "react"

const shake = keyframes`
  8%, 41% {
    transform: translateX(-10px);
  }
  25%, 58% {
    transform: translateX(10px);
  }
  75% {
    transform: translateX(-5px);
  }
  92% {
    transform: translateX(5px);
  }
  0%, 100% {
    transform: translateX(0);
  }
  
`

const animation = `${shake} .5s linear`

export function useWrongPasswordFeedback() {
  const timeout = useRef(0)
  const [show, setShow] = useState(false)

  const callback = useCallback((success: boolean) => {
    setShow(!success)
    if (timeout.current) {
      window.clearTimeout(timeout.current)
    }

    timeout.current = window.setTimeout(() => {
      setShow(false)
    }, 500)
  }, [])

  return [
    {
      animation: show ? animation : undefined,
      error: show,
    },
    callback,
  ] as const
}
